SpotlightGuideAutoScrollDetails class
Details for SpotlightGuideAutoScrollCallback.
Use itemIndex and itemTotal for step copy such as "2 / 5". Use highlightTargetIds when the focused item highlights one or more registered target ids (SpotlightGuideStepItem.targetId or SpotlightGuideStepItem.targetIds). Use key when the item defines a stable business label. When the item highlights the whole portal child, highlightTargetIds is empty.
- Annotations
Constructors
- SpotlightGuideAutoScrollDetails({required int stepIndex, required int itemIndex, required int itemTotal, required SpotlightGuideStepItem item})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlightsWholePortalChild → bool
-
Whether item highlights the whole SpotlightGuidePortal.child.
no setter
-
highlightTargetIds
→ List<
Object> -
Registered target ids currently highlighted by item.
no setter
- item → SpotlightGuideStepItem
-
The focused step item.
final
- itemIndex → int
-
Index of the focused item inside SpotlightGuideStep.items.
final
- itemTotal → int
-
Total number of items in the step.
final
- key → Object?
-
Optional stable key from SpotlightGuideStepItem.key.
no setter
- primaryTargetId → Object?
-
A convenience id for analytics when highlightTargetIds is not empty.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stepIndex → int
-
Index of the SpotlightGuideStep that owns item.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited